all.Thecrms<-function(){
     cat("\n")                                                                      
     cat("-----------------------------------------------------\n")
     cat("    --Theophylline CR input data information--       \n")
     note_for_Thecrss_input()
     cat("-----------------------------------------------------\n")
     cat("\n")
     note_for_close_window()
     ThecrMSpar<-data.frame(subject=c(1,2),Gender=c(0),age=c(0),ht=c(0),CHF=c(0),smoke=c(0),D=c(0),tau=c(0),c=c(0))
     ThecrMSpar<-edit(ThecrMSpar)
##     ThecrMSpar<-ymscheck(ThecrMSpar)
     cat("\n")
     Thecr.ms(length(ThecrMSpar$subject),ThecrMSpar$c,ThecrMSpar$tau,ThecrMSpar$D,ThecrMSpar$ht,ThecrMSpar$age,ThecrMSpar$smoke,ThecrMSpar$Gender,ThecrMSpar$CHF)
     note_for_convergence_plots()
     note_for_plot()
     convergence_plots_con()
     cat("-----------------------------------------------------------\n")
     cat("    --Theophylline CR output data information--            \n")
     note_for_Thecr_output()
     cat("-----------------------------------------------------------\n")  
     show(samplesStats("*"))
     cat("\n") 
     C<-TheCRcpr(1,ThecrMSpar$D,ThecrMSpar$tau)
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Css_pr (mg/L)")     
     show(coutput)
     cat("\n")   
     cal.again()                   
}